@@ -1,6 +1,5 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveFunctor #-}
-{-# LANGUAGE DeriveDataTypeable         #-}
 {-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE TupleSections #-}
 {-# LANGUAGE FlexibleInstances          #-}
@@ -37,7 +36,6 @@ import           Data.Text                          (Text)
 import qualified Data.Text                          as T
 import qualified Data.Text.Lazy.Builder             as TBuilder
 import           Data.Time                          (UTCTime)
-import           Data.Typeable                      (Typeable)
 import           GHC.Generics                       (Generic)
 import           Language.Haskell.TH.Syntax         (Loc)
 import qualified Network.HTTP.Types                 as H
@@ -57,7 +55,7 @@ import           Control.Monad.Reader               (MonadReader (..))
 import Control.DeepSeq (NFData (rnf))
 import Yesod.Core.TypeCache (TypeMap, KeyedTypeMap)
 import Control.Monad.Logger (MonadLoggerIO (..))
-import UnliftIO (MonadUnliftIO (..), UnliftIO (..))
+import UnliftIO (MonadUnliftIO (..))
 
 -- Sessions
 type SessionMap = Map Text ByteString
@@ -333,7 +331,7 @@ data ErrorResponse =
     | NotAuthenticated
     | PermissionDenied !Text
     | BadMethod !H.Method
-    deriving (Show, Eq, Typeable, Generic)
+    deriving (Show, Eq, Generic)
 instance NFData ErrorResponse
 
 ----- header stuff
@@ -411,7 +409,6 @@ data HandlerContents =
     | HCCreated !Text
     | HCWai !W.Response
     | HCWaiApp !W.Application
-    deriving Typeable
 
 instance Show HandlerContents where
     show (HCContent status (TypedContent t _)) = "HCContent " ++ show (status, t)
@@ -440,9 +437,8 @@ instance PrimMonad (WidgetFor site) where
     primitive = liftIO . primitive
 -- | @since 1.4.38
 instance MonadUnliftIO (WidgetFor site) where
-  {-# INLINE askUnliftIO #-}
-  askUnliftIO = WidgetFor $ \wd ->
-                return (UnliftIO (flip unWidgetFor wd))
+  {-# INLINE withRunInIO #-}
+  withRunInIO inner = WidgetFor $ \x -> inner $ flip unWidgetFor x
 instance MonadReader (WidgetData site) (WidgetFor site) where
     ask = WidgetFor return
     local f (WidgetFor g) = WidgetFor $ g . f
@@ -479,9 +475,8 @@ instance MonadReader (HandlerData site site) (HandlerFor site) where
 
 -- | @since 1.4.38
 instance MonadUnliftIO (HandlerFor site) where
-  {-# INLINE askUnliftIO #-}
-  askUnliftIO = HandlerFor $ \r ->
-                return (UnliftIO (flip unHandlerFor r))
+  {-# INLINE withRunInIO #-}
+  withRunInIO inner = HandlerFor $ \x -> inner $ flip unHandlerFor x
 
 instance MonadThrow (HandlerFor site) where
     throwM = liftIO . throwM
@@ -552,9 +547,8 @@ instance MonadReader (HandlerData child master) (SubHandlerFor child master) whe
 
 -- | @since 1.4.38
 instance MonadUnliftIO (SubHandlerFor child master) where
-  {-# INLINE askUnliftIO #-}
-  askUnliftIO = SubHandlerFor $ \r ->
-                return (UnliftIO (flip unSubHandlerFor r))
+  {-# INLINE withRunInIO #-}
+  withRunInIO inner = SubHandlerFor $ \x -> inner $ flip unSubHandlerFor x
 
 instance MonadThrow (SubHandlerFor child master) where
     throwM = liftIO . throwM
